cmd

package
v1.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2023 License: MIT Imports: 27 Imported by: 0

Documentation

Overview

Package cmd is the application CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConcurrentRunner added in v1.1.8

func ConcurrentRunner(p provider.IProvider, cmds []string, args []string) []int

ConcurrentRunner runs the commands concurrently.

func DumpToFile added in v1.1.6

func DumpToFile(file *os.File, finalValues map[string]string) error

DumpToFile dumps the final loaded values to a file. Extension is used to determine the format.

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

func ParseFile added in v1.1.32

func ParseFile(ctx context.Context, file *os.File) (map[string]any, error)

ParseFile parse file. Extension is used to determine the format.

Types

This section is empty.

Jump to